Re-exports
pub use sequoia_gpg_agent;
Structs
- Backend
- Device
- A Device exposes the (usable) keys managed by a particular gpg-agent.
- Key
- Weak
Device - A
Device, but with a weak reference to the data.
pub use sequoia_gpg_agent;Device, but with a weak reference to the data.